==> wildfly-ee-dist-24.0.0.Beta1-src.zip: wildfly-24.0.0.Beta1-src/jsf/subsystem/src/main/java/org/jboss/as/jsf/deployment/JSFBeanValidationFactoryProcessor.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2013, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.as.jsf.deployment;

import static javax.faces.validator.BeanValidator.VALIDATOR_FACTORY_KEY;

import javax.validation.ValidatorFactory;

import org.jboss.as.ee.beanvalidation.BeanValidationAttachments;
import org.jboss.as.server.deployment.DeploymentPhaseContext;
import org.jboss.as.server.deployment.DeploymentUnit;
import org.jboss.as.server.deployment.DeploymentUnitProcessingException;
import org.jboss.as.server.deployment.DeploymentUnitProcessor;
import org.jboss.as.web.common.ServletContextAttribute;

/**
 * Deployment processor that adds the Jakarta Contexts and Dependency Injection enabled ValidatorFactory to the servlet context.
 *
 * @author Farah Juma
 */
public class JSFBeanValidationFactoryProcessor implements DeploymentUnitProcessor {

    @Override
    public void deploy(DeploymentPhaseContext phaseContext) throws DeploymentUnitProcessingException {

        final DeploymentUnit deploymentUnit = phaseContext.getDeploymentUnit();

        if(JsfVersionMarker.isJsfDisabled(deploymentUnit)) {
            return;
        }

        // Get the Jakarta Contexts and Dependency Injection enabled ValidatorFactory and add it to the servlet context
        ValidatorFactory validatorFactory = deploymentUnit.getAttachment(BeanValidationAttachments.VALIDATOR_FACTORY);
        if(validatorFactory != null) {
            deploymentUnit.addToAttachmentList(ServletContextAttribute.ATTACHMENT_KEY,
                    new ServletContextAttribute(VALIDATOR_FACTORY_KEY, validatorFactory));
        }
    }

    @Override
    public void undeploy(DeploymentUnit context) {
    }
}

==> wildfly-ee-dist-33.0.0.Beta1-src.zip: wildfly-33.0.0.Beta1-src/jsf/subsystem/src/main/java/org/jboss/as/jsf/deployment/JSFBeanValidationFactoryProcessor.java <==
/*
 * Copyright The WildFly Authors
 * SPDX-License-Identifier: Apache-2.0
 */

package org.jboss.as.jsf.deployment;

import static jakarta.faces.validator.BeanValidator.VALIDATOR_FACTORY_KEY;

import jakarta.validation.ValidatorFactory;

import org.jboss.as.ee.beanvalidation.BeanValidationAttachments;
import org.jboss.as.server.deployment.DeploymentPhaseContext;
import org.jboss.as.server.deployment.DeploymentUnit;
import org.jboss.as.server.deployment.DeploymentUnitProcessingException;
import org.jboss.as.server.deployment.DeploymentUnitProcessor;
import org.jboss.as.web.common.ServletContextAttribute;

/**
 * Deployment processor that adds the Jakarta Contexts and Dependency Injection enabled ValidatorFactory to the servlet context.
 *
 * @author Farah Juma
 */
public class JSFBeanValidationFactoryProcessor implements DeploymentUnitProcessor {

    @Override
    public void deploy(DeploymentPhaseContext phaseContext) throws DeploymentUnitProcessingException {

        final DeploymentUnit deploymentUnit = phaseContext.getDeploymentUnit();

        if(JsfVersionMarker.isJsfDisabled(deploymentUnit)) {
            return;
        }

        // Get the Jakarta Contexts and Dependency Injection enabled ValidatorFactory and add it to the servlet context
        ValidatorFactory validatorFactory = deploymentUnit.getAttachment(BeanValidationAttachments.VALIDATOR_FACTORY);
        if(validatorFactory != null) {
            deploymentUnit.addToAttachmentList(ServletContextAttribute.ATTACHMENT_KEY,
                    new ServletContextAttribute(VALIDATOR_FACTORY_KEY, validatorFactory));
        }
    }
}
